from spectral_encoding.datamodel import Sensor, SpectralBand

Landsat9 = Sensor(
    name="Landsat 9",
    bands=[
        SpectralBand(
            description="PAN",
            standard="P",
            fwhm_min=503,
            fwhm_max=675,
            fwhm_ratio=697,
            gsd=150
        ),
        SpectralBand(
            description="CoastalAerosols",
            standard="A",
            fwhm_min=436,
            fwhm_max=450,
            fwhm_ratio=871,
            gsd=300
        ),
        SpectralBand(
            description="Blue",
            standard="B",
            fwhm_min=452,
            fwhm_max=511,
            fwhm_ratio=798,
            gsd=300
        ),
        SpectralBand(
            description="Green",
            standard="G",
            fwhm_min=533,
            fwhm_max=589,
            fwhm_ratio=894,
            gsd=300
        ),
        SpectralBand(
            description="Red",
            standard="R",
            fwhm_min=636,
            fwhm_max=672,
            fwhm_ratio=894,
            gsd=300
        ),
        SpectralBand(
            description="NIR",
            standard="N",
            fwhm_min=851,
            fwhm_max=878,
            fwhm_ratio=910,
            gsd=300
        ),
        SpectralBand(
            description="SWIR1",
            standard="S1",
            fwhm_min=1566,
            fwhm_max=1651,
            fwhm_ratio=828,
            gsd=300
        ),
        SpectralBand(
            description="SWIR2",
            standard="S2",
            fwhm_min=2106,
            fwhm_max=2294,
            fwhm_ratio=877,
            gsd=300
        ),
        SpectralBand(
            description="Cirrus",
            standard="C",
            fwhm_min=1364,
            fwhm_max=1384,
            fwhm_ratio=814,
            gsd=300
        ),
        SpectralBand(
            description="TIR1",
            standard="T1",
            fwhm_min=10453,
            fwhm_max=11199,
            fwhm_ratio=660,
            gsd=300
        ),
        SpectralBand(
            description="TIR2",
            standard="T2",
            fwhm_min=11578,
            fwhm_max=12495,
            fwhm_ratio=676,
            gsd=300
        ),
    ]
)

Landsat8 = Sensor(
    name="Landsat 8",
    bands=[
        SpectralBand(
            description="CoastalAerosol",
            standard="A",
            fwhm_min=435,
            fwhm_max=450,
            fwhm_ratio=834,
            gsd=300
        ),
        SpectralBand(
            description="Blue",
            standard="B",
            fwhm_min=453,
            fwhm_max=512,
            fwhm_ratio=833,
            gsd=300
        ),
        SpectralBand(
            description="Green",
            standard="G",
            fwhm_min=533,
            fwhm_max=590,
            fwhm_ratio=881,
            gsd=300
        ),
        SpectralBand(
            description="Red",
            standard="R",
            fwhm_min=636,
            fwhm_max=673,
            fwhm_ratio=878,
            gsd=300
        ),
        SpectralBand(
            description="NIR",
            standard="N",
            fwhm_min=851,
            fwhm_max=878,
            fwhm_ratio=841,
            gsd=300
        ),
        SpectralBand(
            description="Cirrus",
            standard="C",
            fwhm_min=1364,
            fwhm_max=1383,
            fwhm_ratio=779,
            gsd=300
        ),
        SpectralBand(
            description="SWIR1",
            standard="S1",
            fwhm_min=1567,
            fwhm_max=1651,
            fwhm_ratio=804,
            gsd=300
        ),
        SpectralBand(
            description="SWIR2",
            standard="S2",
            fwhm_min=2108,
            fwhm_max=2294,
            fwhm_ratio=843,
            gsd=300
        ),
        SpectralBand(
            description="Pan",
            standard="P",
            fwhm_min=504,
            fwhm_max=675,
            fwhm_ratio=844,
            gsd=150
        ),
        SpectralBand(
            description="TIR1",
            standard="T1",
            fwhm_min=10599,
            fwhm_max=11181,
            fwhm_ratio=681,
            gsd=300
        ),
        SpectralBand(
            description="TIR2",
            standard="T2",
            fwhm_min=11506,
            fwhm_max=12505,
            fwhm_ratio=789,
            gsd=300
        ),
    ]
)

Sentinel2 = Sensor(
    name="Sentinel-2",
    bands=[
        SpectralBand(
            description="CoastalAerosol",
            standard="A",
            fwhm_min=435,
            fwhm_max=452,
            fwhm_ratio=608,
            gsd=600
        ),
        SpectralBand(
            description="Blue",
            standard="B",
            fwhm_min=470,
            fwhm_max=523,
            fwhm_ratio=422,
            gsd=100
        ),
        SpectralBand(
            description="Green",
            standard="G",
            fwhm_min=543,
            fwhm_max=577,
            fwhm_ratio=708,
            gsd=100
        ),
        SpectralBand(
            description="Red",
            standard="R",
            fwhm_min=650,
            fwhm_max=679,
            fwhm_ratio=812,
            gsd=100
        ),
        SpectralBand(
            description="RedEdge1",
            standard="RE1",
            fwhm_min=698,
            fwhm_max=711,
            fwhm_ratio=794,
            gsd=200
        ),
        SpectralBand(
            description="RedEdge2",
            standard="RE2",
            fwhm_min=734,
            fwhm_max=747,
            fwhm_ratio=817,
            gsd=200
        ),
        SpectralBand(
            description="RedEdge3",
            standard="RE3",
            fwhm_min=774,
            fwhm_max=792,
            fwhm_ratio=663,
            gsd=200
        ),
        SpectralBand(
            description="NIR",
            standard="N",
            fwhm_min=783,
            fwhm_max=897,
            fwhm_ratio=452,
            gsd=100
        ),
        SpectralBand(
            description="RedEdge4",
            standard="RE4",
            fwhm_min=855,
            fwhm_max=874,
            fwhm_ratio=829,
            gsd=200
        ),
        SpectralBand(
            description="WaterVapor",
            standard="WV",
            fwhm_min=936,
            fwhm_max=954,
            fwhm_ratio=869,
            gsd=600
        ),
        SpectralBand(
            description="Cirrus",
            standard="C",
            fwhm_min=1359,
            fwhm_max=1388,
            fwhm_ratio=783,
            gsd=600
        ),
        SpectralBand(
            description="SWIR1",
            standard="S1",
            fwhm_min=1569,
            fwhm_max=1658,
            fwhm_ratio=879,
            gsd=200
        ),
        SpectralBand(
            description="SWIR2",
            standard="S2",
            fwhm_min=2113,
            fwhm_max=2286,
            fwhm_ratio=752,
            gsd=200
        ),
    ]
)